/*!***************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js!./node_modules/sass-loader/dist/cjs.js!./src/UniversalUploaderInline.scss ***!
  \***************************************************************************************************************************/
body {
  --uuw-background: #FFF;
  --uuw-border-color: #CCC;
  --uuw-color: #333;
  --uuw-placeholder-text-color: #AAA;
  --uuw-placeholder-destak-color: #417690;
  --uuw-dropzone-background: rgba(255, 255, 255, 0.8);
  --uuw-file-preview-border: #BFBFBF;
  --uuw-file-preview-shadow: rgba(0, 0, 0, 0.3);
  --uuw-add-file-background: #EFEFEF;
  --uuw-add-file-color: #AAA;
}
@media (prefers-color-scheme: dark) {
  body {
    --uuw-background: #121212;
    --uuw-border-color: #CCC;
    --uuw-color: #333;
    --uuw-placeholder-text-color: #AAA;
    --uuw-placeholder-destak-color: #417690;
    --uuw-dropzone-background: rgba(0, 0, 0, 0.8);
    --uuw-file-preview-border: #333;
    --uuw-file-preview-shadow: rgba(0, 0, 0, 0.3);
    --uuw-add-file-background: #333;
    --uuw-add-file-color: #CCC;
  }
}

@keyframes arrow-flashing {
  from {
    opacity: 0;
    transform: scale(0) translateY(12px);
  }
  to {
    opacity: 1;
    transform: scale(1) translateY(0);
  }
}
/*****/
/*****/
/*****/
.uuw-inline-root, .uuw-inline-root * {
  box-sizing: border-box;
}

.uuw-inline-root {
  /* base widget */
  /* behaviour */
  user-select: none;
  /* sizing */
  min-width: 300px;
  height: 200px;
  /* shape */
  border-radius: 5px;
  padding: 5px;
  /* styles */
  background-color: var(--uuw-background);
  border: 3px dashed var(--uuw-border-color);
  color: var(--uuw-color);
  /* positioning */
  position: relative;
  /* overflowing */
  overflow-y: hidden;
  overflow-x: auto;
  /* childs */
  display: flex;
  flex-direction: row;
  align-items: stretch;
  /* empty label */
  /* drop label */
  /* file preview */
  /* files carousel */
  /* add button */
}
.uuw-inline-root input[type=file],
.uuw-inline-root input[type=checkbox] {
  display: none;
}
.uuw-inline-root .uuw-empty {
  /* positioning */
  position: absolute;
  left: 0;
  right: 0;
  bottom: 0;
  top: 0;
  z-index: 50;
  /* display */
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  /* text */
  text-align: center;
  font-size: 1.3em;
  font-weight: bold;
  letter-spacing: 0.05em;
  color: var(--uuw-placeholder-text-color);
  /* behaviour */
  cursor: pointer;
  /* animations */
  height: 0;
  opacity: 0;
  overflow: hidden;
  transition: opacity 0.3s ease, height 0.3s ease;
  /* childs */
}
.uuw-inline-root .uuw-empty > svg {
  width: 50px;
  height: 50px;
  margin-bottom: 30px;
  transition: width 0.3s ease, height 0.3s ease, margin 0.3s ease;
}
.uuw-inline-root .uuw-empty:hover > svg {
  width: 80px;
  height: 80px;
  margin-bottom: 10px;
}
.uuw-inline-root .uuw-empty > span {
  text-align: center;
}
.uuw-inline-root .uuw-empty > span span {
  color: var(--uuw-placeholder-destak-color);
}
.uuw-inline-root:not(.non-empty) .uuw-empty {
  height: 100%;
  opacity: 1;
}
.uuw-inline-root.drop-zone .uuw-empty {
  height: 0;
  opacity: 0;
}
.uuw-inline-root .uuw-drop-label {
  /* positioning */
  position: absolute;
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  z-index: 55;
  /* style */
  background: var(--uuw-dropzone-background);
  /* display */
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  /* text */
  text-align: center;
  font-size: 1.3em;
  font-weight: bold;
  letter-spacing: 0.05em;
  color: var(--uuw-placeholder-text-color);
  /* behaviour */
  cursor: grabbing;
  /* animations */
  height: 0;
  opacity: 0;
  overflow: hidden;
  transition: opacity 0.3s ease, height 0.3s ease;
  /* childs */
}
.uuw-inline-root .uuw-drop-label > svg {
  width: 90px;
  height: 90px;
  margin-bottom: 20px;
  transition: width 0.3s ease, height 0.3s ease, margin 0.3s ease;
}
.uuw-inline-root .uuw-drop-label > svg path:last-child {
  transform-origin: 50% 100%;
  animation: arrow-flashing 1.1s;
  animation-timing-function: ease-in;
  animation-fill-mode: both;
  animation-iteration-count: infinite;
  animation-delay: 0.3s;
}
.uuw-inline-root .uuw-drop-label > span {
  text-align: center;
}
.uuw-inline-root .uuw-drop-label > span span {
  color: var(--uuw-placeholder-destak-color);
}
.uuw-inline-root.drop-zone .uuw-drop-label {
  height: 100%;
  opacity: 1;
}
.uuw-inline-root .inline-related {
  /* style */
  border: 1px solid var(--uuw-file-preview-border);
  box-shadow: 0 0 4px 0 var(--uuw-file-preview-shadow);
  /* shape */
  width: 160px;
  margin: 0 5px;
  border-radius: 5px;
  overflow: hidden;
  /* behaviour */
  cursor: pointer;
  /* positioning */
  position: relative;
  /* childs */
}
.uuw-inline-root .inline-related img {
  /* sizing */
  width: 100%;
  height: 100%;
  /* display mode */
  object-fit: cover;
  object-position: center;
}
.uuw-inline-root .inline-related .uuw-file-preview-container {
  width: 100%;
  height: 100%;
}
.uuw-inline-root .inline-related .uuw-delete-icon,
.uuw-inline-root .inline-related .uuw-preview-icon {
  /* shape */
  width: 32px;
  height: 32px;
  border-radius: 0 5px 0 0;
  /* styles */
  border: 1px solid #BFBFBF;
  border-top: none;
  border-right: none;
  background-color: #F5F5F5;
  opacity: 0.6;
  /* positioning */
  position: absolute;
  right: 0;
  top: 0;
  z-index: 45;
  /* display */
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  /* animations */
  transition: opacity 0.3s ease;
  /* icon */
}
.uuw-inline-root .inline-related .uuw-delete-icon svg,
.uuw-inline-root .inline-related .uuw-preview-icon svg {
  width: 16px;
  height: auto;
  transform: none;
  transition: transform 0.3s ease;
}
.uuw-inline-root .inline-related .uuw-delete-icon:hover,
.uuw-inline-root .inline-related .uuw-preview-icon:hover {
  opacity: 1;
}
.uuw-inline-root .inline-related .uuw-delete-icon:hover svg,
.uuw-inline-root .inline-related .uuw-preview-icon:hover svg {
  transform: scale(1.3);
}
.uuw-inline-root .inline-related .uuw-preview-icon:not(.uuw-only-preview) {
  top: 32px;
  border-radius: 0;
}
.uuw-inline-root .inline-related.empty-form {
  display: none;
}
.uuw-inline-root .inline-related.deleted {
  display: none;
}
.uuw-inline-root > div {
  height: 100%;
  width: auto;
  display: flex;
  flex-direction: row;
  align-items: stretch;
}
.uuw-inline-root .uuw-add-file-btn {
  /* shape */
  border-radius: 5px;
  padding: 15px;
  width: 160px;
  max-width: 160px;
  /* styles */
  border: 1px solid var(--uuw-file-preview-border);
  box-shadow: 0 0 4px 0 var(--uuw-file-preview-shadow);
  background: var(--uuw-add-file-background);
  color: var(--uuw-add-file-color);
  /* display */
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  display: none;
  /* behaviour */
  cursor: pointer;
}
.uuw-inline-root .uuw-add-file-btn svg {
  fill: var(--uuw-add-file-color);
  margin-bottom: 30px;
  width: 60px;
  height: auto;
  transition: margin 0.3s ease, width 0.3s ease, height 0.3s ease;
}
.uuw-inline-root .uuw-add-file-btn:hover svg {
  margin-bottom: 10px;
  width: 80px;
  height: auto;
}
.uuw-inline-root .uuw-add-file-btn > span {
  font-weight: bold;
  text-align: center;
  font-size: 1rem;
}
.uuw-inline-root.non-empty .uuw-add-file-btn:not(.visible-by-number) {
  display: none;
}
.uuw-inline-root.non-empty .uuw-add-file-btn.visible-by-number {
  display: flex;
}
.uuw-inline-root:not(.non-empty) .uuw-add-file-btn {
  display: none;
}

@keyframes arrow-flashing {
  from {
    opacity: 0;
    transform: scale(0) translateY(12px);
  }
  to {
    opacity: 1;
    transform: scale(1) translateY(0);
  }
}
/*****/
/*****/
/*****/
:root {
  --uuw-modal-overlay: rgba(0, 0, 0, 0.6);
  --uuw-modal-file-background: #fff;
  --uuw-modal-closebutton-background: #fff;
  --uuw-modal-closebutton-shadow: rgba(0, 0, 0, 0.2);
  --uuw-modal-closebutton-color: #333;
}

#uuw-modal-element {
  /* position */
  position: fixed;
  z-index: 150;
  left: 0;
  top: 0;
  /* size */
  width: 100%;
  height: 100vh;
  /* styles */
  background: var(--uuw-modal-overlay);
  /* behaviour */
  user-select: none;
  cursor: pointer;
  /* display */
  display: flex;
  align-items: center;
  justify-content: center;
  /* animations */
}
#uuw-modal-element.visible {
  transition: opacity 0.3s;
}
#uuw-modal-element.hide {
  transition: opacity 0.3s;
  opacity: 0;
}
#uuw-modal-element .uuw-modal-file-preview {
  width: 90%;
  height: 80%;
  position: relative;
}
#uuw-modal-element .uuw-modal-file-preview .uuw-modal-pdf-preview-item {
  height: 100%;
}
#uuw-modal-element .uuw-modal-file-preview video,
#uuw-modal-element .uuw-modal-file-preview img {
  background: var(--uuw-modal-file-background);
  width: 100%;
  height: 100%;
  object-fit: contain;
  object-position: center;
  cursor: default;
}
#uuw-modal-element .uuw-modal-file-preview .uuw-modal-close {
  position: absolute;
  right: 0;
  top: 0;
  transform: translate(50%, -50%);
  z-index: 100;
  width: 40px;
  height: 40px;
  border-radius: 50%;
  display: flex;
  align-items: center;
  justify-content: center;
  background: var(--uuw-modal-closebutton-background);
  filter: drop-shadow(0 0 5px var(--uuw-modal-closebutton-shadow));
}
#uuw-modal-element .uuw-modal-file-preview .uuw-modal-close svg {
  width: 18px;
  height: auto;
  fill: var(--uuw-modal-closebutton-color);
}
@media (max-width: 768px) {
  #uuw-modal-element .uuw-modal-file-preview .uuw-modal-close {
    transform: none;
    box-shadow: none;
    border-radius: unset;
  }
}
